@@ -34,7 +34,7 @@ class rabbitmq_helper():
     @retry(pika.exceptions.AMQPConnectionError, delay=5, jitter=(1, 3))
     def listen(self):
         credentials = pika.PlainCredentials(self.user, self.pwd)  # mq用户名和密码
-        connection = pika.BlockingConnection(pika.ConnectionParameters(host = self.host,port = 5672,virtual_host = '/',credentials = credentials))
+        connection = pika.BlockingConnection(pika.ConnectionParameters(host = self.host,port = 5672,virtual_host = '/',credentials = credentials,heartbeat=5))
         self.channel = connection.channel()
         for i in self.message_dict.keys():
             self.channel.basic_consume(i,self.callback);
